==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnTemplateContextDescription } from "./WebColumnTemplateContextDescription";
/**
 * @hidden
 */
var WebColumnTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnTemplateContextDescriptionMetadata, _super);
    function WebColumnTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnTemplateContextDescriptionMetadata.b = function (a) {
        if (WebColumnTemplateContextDescriptionMetadata.a == null) {
            WebColumnTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnTemplateContextDescriptionMetadata.c(WebColumnTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebColumnTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnTemplateContextDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "ExportedType:WebColumn");
        a.item("Column", "ExportedType:WebColumn");
    };
    WebColumnTemplateContextDescriptionMetadata.d = function (a) {
        WebColumnTemplateContextDescriptionMetadata.b(a);
        a.aa("WebColumnTemplateContext", function () { return new WebColumnTemplateContextDescription(); });
        a.z("WebColumnTemplateContext", WebColumnTemplateContextDescriptionMetadata.a);
    };
    WebColumnTemplateContextDescriptionMetadata.$t = markType(WebColumnTemplateContextDescriptionMetadata, 'WebColumnTemplateContextDescriptionMetadata');
    WebColumnTemplateContextDescriptionMetadata.a = null;
    return WebColumnTemplateContextDescriptionMetadata;
}(Base));
export { WebColumnTemplateContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnTemplateContextDescription } from "./WebColumnTemplateContextDescription";
/**
 * @hidden
 */
var WebColumnTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnTemplateContextDescriptionMetadata, _super);
    function WebColumnTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnTemplateContextDescriptionMetadata.b = function (a) {
        if (WebColumnTemplateContextDescriptionMetadata.a == null) {
            WebColumnTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnTemplateContextDescriptionMetadata.c(WebColumnTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebColumnTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnTemplateContextDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebColumn");
        a.item("Column", "ExportedType:WebColumn");
    };
    WebColumnTemplateContextDescriptionMetadata.d = function (a) {
        WebColumnTemplateContextDescriptionMetadata.b(a);
        a.ac("WebColumnTemplateContext", function () { return new WebColumnTemplateContextDescription(); });
        a.ab("WebColumnTemplateContext", WebColumnTemplateContextDescriptionMetadata.a);
    };
    WebColumnTemplateContextDescriptionMetadata.$t = markType(WebColumnTemplateContextDescriptionMetadata, 'WebColumnTemplateContextDescriptionMetadata');
    WebColumnTemplateContextDescriptionMetadata.a = null;
    return WebColumnTemplateContextDescriptionMetadata;
}(Base));
export { WebColumnTemplateContextDescriptionMetadata };
